@@ -3,7 +3,7 @@ from .rule import Rule, SearchMode
 # KEYS
 GPU_TYPE = Rule.from_indexed("GPU_TYPE", ["H100", "A100", "A800"])
 GPU_NUM = Rule.from_indexed("GPU_NUM", [1, 2, 4, 8], matches=SearchMode.BINARY_FLOOR)
-MODEL_NAME = Rule.from_indexed("MODEL_NAME", ["LLAMA_7B", "LLAMA_20B", "LLAMA_70B"])
+MODEL_NAME = Rule.from_indexed("MODEL_NAME", ["LLAMA_7B", "LLAMA_20B", "LLAMA_70B", "LLAMA_100B"])
 CTX_LEN = Rule.from_indexed("CTX_LEN", [512, 2048], matches=SearchMode.BINARY_CEIL)
 BATCH_SIZE = Rule.from_indexed("BATCH_SIZE", [1, 8, 32, 128, 512], matches=SearchMode.BINARY_CEIL)
 MAX_TOKEN_NUM = Rule.from_indexed("MAX_TOKEN_NUM", [64 * 1024, 256 * 1024, 1024 * 1024],
