@@ -10,7 +10,8 @@ from .agent import (
     ReWOOAgent,
 )
 from .classifier import IntentClassifier
-from .sql import SQLiteManger, SqlManager, SqlCall
+from .sql import SqlManager, MongoDBManager, DBResult, DBStatus
+from .sql_call import SqlCall
 from .tools.http_tool import HttpTool
 
 __all__ = [
@@ -28,8 +29,10 @@ __all__ = [
     "ReWOOAgent",
     "IntentClassifier",
     "SentenceSplitter",
-    "SQLiteManger",
     "SqlManager",
+    "MongoDBManager",
+    "DBResult",
+    "DBStatus",
     "SqlCall",
     "HttpTool",
 ]
