@@ -19,7 +19,5 @@ class DocxReader(LazyLLMReaderBase):
                 text = docx2txt.process(f)
         else:
             text = docx2txt.process(file)
-        metadata = {"file_name": file.name}
-        if extra_info is not None: metadata.update(extra_info)
 
-        return [DocNode(text=text, metadata=metadata)]
+        return [DocNode(text=text, global_metadata=extra_info)]
