@@ -6,6 +6,7 @@ from .index_base import IndexBase
 # ---------------------------------------------------------------------------- #
 
 LAZY_ROOT_NAME = "lazyllm_root"
+LAZY_IMAGE_GROUP = "Image"
 EMBED_DEFAULT_KEY = '__default__'
 
 # ---------------------------------------------------------------------------- #
@@ -15,6 +16,10 @@ class StoreBase(ABC):
     def update_nodes(self, nodes: List[DocNode]) -> None:
         pass
 
+    @abstractmethod
+    def update_doc_meta(self, filepath: str, metadata: dict) -> None:
+        pass
+
     @abstractmethod
     def remove_nodes(self, group_name: str, uids: Optional[List[str]] = None) -> None:
         pass
