@@ -4,29 +4,14 @@ import requests
 from urllib.parse import urljoin
 
 import lazyllm
-from lazyllm.launcher import Status
 from lazyllm.module.utils import update_config, TrainConfig, uniform_sft_dataset
+from ..services import ClientBase
 
 
-class LocalTrainClient:
+class LocalTrainClient(ClientBase):
 
     def __init__(self, url):
-        self.url = url
-
-    def uniform_status(self, status):
-        if status == 'Invalid':
-            res = 'Invalid'
-        elif Status[status] == Status.Done:
-            res = 'Done'
-        elif Status[status] == Status.Cancelled:
-            res = 'Cancelled'
-        elif Status[status] == Status.Failed:
-            res = 'Failed'
-        elif Status[status] == Status.Running:
-            res = 'Running'
-        else:  # TBSubmitted, InQueue, Pending
-            res = 'Pending'
-        return res
+        super().__init__(urljoin(url, 'v1/fine_tuning/'))
 
     def train(self, train_config, token):
         """
@@ -61,10 +46,10 @@ class LocalTrainClient:
         - lora_r: The LoRA rank.
         - lora_alpha: The LoRA alpha parameter.
         """
-        url = urljoin(self.url, 'v1/fine_tuning/jobs')
+        url = urljoin(self.url, 'jobs')
         headers = {
-            "Content-Type": "application/json",
-            "token": token,
+            'Content-Type': 'application/json',
+            'token': token,
         }
         train_config = update_config(train_config, TrainConfig)
         data = {
@@ -79,7 +64,7 @@ class LocalTrainClient:
                 'num_train_epochs': train_config['num_epochs'],
                 'learning_rate': train_config['learning_rate'],
                 'lr_scheduler_type': train_config['lr_scheduler_type'],
-                'per_device_train_batch_size': train_config['batch_size'],
+                'per_device_train_batch_size': train_config['batch_size'] // train_config['num_gpus'],
                 'cutoff_len': train_config['cutoff_len'],
                 'lora_r': train_config['lora_r'],
                 'lora_alpha': train_config['lora_alpha'],
@@ -111,9 +96,9 @@ class LocalTrainClient:
         Raises:
         - Exception: If an error occurs during the request, it will be logged and an error message will be returned.
         """
-        url = urljoin(self.url, f'v1/fine_tuning/jobs/{job_id}/cancel')
+        url = urljoin(self.url, f'jobs/{job_id}/cancel')
         headers = {
-            "token": token,
+            'token': token,
         }
         try:
             response = requests.post(url, headers=headers)
@@ -122,11 +107,11 @@ class LocalTrainClient:
             if status == 'Cancelled':
                 return True
             else:
-                return f"Failed to cancel task. Final status is {status}"
+                return f'Failed to cancel task. Final status is {status}'
         except Exception as e:
             status = str(e)
             lazyllm.LOG.error(str(e))
-            return f"Failed to cancel task. Because: {str(e)}"
+            return f'Failed to cancel task. Because: {str(e)}'
 
     def get_training_cost(self, token, job_id):
         """
@@ -147,14 +132,14 @@ class LocalTrainClient:
         - Exception: If an error occurs during the request, it will be logged and an error message will be returned.
 
         """
-        url = urljoin(self.url, f'v1/fine_tuning/jobs/{job_id}')
-        headers = {"token": token}
+        url = urljoin(self.url, f'jobs/{job_id}')
+        headers = {'token': token}
         try:
             response = requests.get(url, headers=headers)
             response.raise_for_status()
             return response.json()['cost']
         except Exception as e:
-            error = f"Failed to get cost. Because: {str(e)}"
+            error = f'Failed to get cost. Because: {str(e)}'
             lazyllm.LOG.error(error)
             return error
 
@@ -175,8 +160,8 @@ class LocalTrainClient:
         Raises:
         - Exception: If an error occurs during the request, it will be logged.
         """
-        url = urljoin(self.url, f'v1/fine_tuning/jobs/{job_id}')
-        headers = {"token": token}
+        url = urljoin(self.url, f'jobs/{job_id}')
+        headers = {'token': token}
         try:
             response = requests.get(url, headers=headers)
             response.raise_for_status()
@@ -203,14 +188,14 @@ class LocalTrainClient:
         Raises:
         - Exception: If an error occurs during the request, it will be logged.
         """
-        url = urljoin(self.url, f'v1/fine_tuning/jobs/{job_id}/events')
-        headers = {"token": token}
+        url = urljoin(self.url, f'jobs/{job_id}/events')
+        headers = {'token': token}
         try:
             response = requests.get(url, headers=headers)
             response.raise_for_status()
             return response.json()['log']
         except Exception as e:
-            lazyllm.LOG.error(f"Failed to get log. Because: {str(e)}")
+            lazyllm.LOG.error(f'Failed to get log. Because: {str(e)}')
             return None
 
     def get_all_trained_models(self, token):
@@ -227,8 +212,8 @@ class LocalTrainClient:
         Raises:
         - Exception: If an error occurs during the request, it will be logged.
         """
-        url = urljoin(self.url, 'v1/fine_tuning/jobs')
-        headers = {"token": token}
+        url = urljoin(self.url, 'jobs')
+        headers = {'token': token}
         try:
             response = requests.get(url, headers=headers)
             response.raise_for_status()
@@ -238,7 +223,7 @@ class LocalTrainClient:
                 res.append([job_id, job['fine_tuned_model'], job['status']])
             return res
         except Exception as e:
-            lazyllm.LOG.error(f"Failed to get log. Because: {e}")
+            lazyllm.LOG.error(f'Failed to get log. Because: {e}')
             return None
 
 class OnlineTrainClient:
@@ -348,10 +333,10 @@ class OnlineTrainClient:
             if res == 'Cancelled':
                 return True
             else:
-                return f"Failed to cancel task. Final info is {res}"
+                return f'Failed to cancel task. Final info is {res}'
         except Exception as e:
             lazyllm.LOG.error(str(e))
-            return f"Failed to cancel task. Because: {str(e)}"
+            return f'Failed to cancel task. Because: {str(e)}'
 
     def get_training_log(self, token, job_id, source, target_path=None):
         """
@@ -379,7 +364,7 @@ class OnlineTrainClient:
                 json.dump(log, log_file, indent=4, ensure_ascii=False)
             return save_path
         except Exception as e:
-            lazyllm.LOG.error(f"Failed to get log. Because: {e}")
+            lazyllm.LOG.error(f'Failed to get log. Because: {e}')
             return None
 
     def get_training_cost(self, token, job_id, source):
@@ -403,20 +388,22 @@ class OnlineTrainClient:
             res = m._query_finetuning_cost(job_id)
             return res
         except Exception as e:
-            error = f"Failed to get cost. Because: {str(e)}"
+            error = f'Failed to get cost. Because: {str(e)}'
             lazyllm.LOG.error(error)
             return error
 
-    def validate_api_key(self, token, source):
+    def validate_api_key(self, token, source, secret_key=None):
         """
         Validates the API key for a given supplier.
 
         Args:
         - token (str): API-Key provided by the user, used for authentication.
         - source (str): Specifies the supplier. Supported suppliers are 'openai', 'glm' and 'qwen'.
+        - secret_key (str): The secret key provided by the user for authentication,
+            required only when the source is 'sensenova'. Default is None.
 
         Returns:
         - bool: True if the API key is valid, False otherwise.
         """
-        m = lazyllm.OnlineChatModule(source=source, api_key=token)
+        m = lazyllm.OnlineChatModule(source=source, api_key=token, secret_key=secret_key)
         return m._validate_api_key()
